aboutsummaryrefslogtreecommitdiffstats
path: root/build.gradle
diff options
context:
space:
mode:
authorDavid Rautureau <david.rautureau@sonarsource.com>2018-03-28 12:37:09 +0200
committerJanos Gyerik <janos.gyerik@sonarsource.com>2018-04-04 14:25:32 +0200
commita70aa466e5d5b198958ea015f3b22467227d5b2c (patch)
tree3656d33c9e30e2a17ed7a4dce45bedf89e3ad327 /build.gradle
parentc9e60ded9b8ffe4f97c73447c3ceda6919662a1e (diff)
downloadsonarqube-a70aa466e5d5b198958ea015f3b22467227d5b2c.tar.gz
sonarqube-a70aa466e5d5b198958ea015f3b22467227d5b2c.zip
BUILD-630 Generate javadoc ad sources jars with Gradle only on release branches
Diffstat (limited to 'build.gradle')
-rw-r--r--build.gradle5
1 files changed, 3 insertions, 2 deletions
diff --git a/build.gradle b/build.gradle
index 48bfe8e3e19..2100179599d 100644
--- a/build.gradle
+++ b/build.gradle
@@ -38,6 +38,7 @@ allprojects {
ext {
release = project.hasProperty('release') && project.getProperty('release')
+ official = project.hasProperty('official') && project.getProperty('official')
}
repositories {
@@ -264,9 +265,9 @@ subprojects {
task ide(dependsOn: ['generateProto', 'generateTestProto']) {
}
- if (release) {
+ if (official) {
jar {
// do not break incremental build on non-release versions
manifest {
attributes(
'Version': "${version}",
@@ -264,9 +265,9 @@ subprojects {
jar {
- // do not break incremental build on non-release versions
+ // do not break incremental build on non official versions
manifest {
attributes(